export * from './abi'
export * from './utils'

// Viem Hex like type
type Hex = `0x${string}`

/**
 * The eco protocol chain configuration type. Represents
 * all the deployed contracts on a chain.
 * 
 * @packageDocumentation
 * @module index
 */
export type EcoChainConfig = {
  Prover?: Hex
  IntentSource: Hex
  Inbox: Hex
  HyperProver: Hex
}

/**
 * The chain ids for the eco protocol
 * 
 * @packageDocumentation
 * @module index
 */
export type EcoChainIds = "10" | "8453" | "42161" | "10-pre" | "8453-pre" | "42161-pre"

/**
 * This file contains the addresses of the contracts deployed on the EcoProtocol network
 * for the current npm package release. The addresses are generated by the deploy script.
 * 
 * @packageDocumentation
 * @module index
*/
export const EcoProtocolAddresses: Record<EcoChainIds, EcoChainConfig> = 
  {
    "10": {
      "IntentSource": "0x983E3F7d2B1Ac28988125BA025f8b390132AFD98",
      "Inbox": "0x1c84ebA615203406Caf02e17F4A2D188a8A6bE93",
      "HyperProver": "0x486cD7EC5D37ff9bAF1be93e0c803305b602C007"
    },
    "8453": {
      "IntentSource": "0x983E3F7d2B1Ac28988125BA025f8b390132AFD98",
      "Inbox": "0x1c84ebA615203406Caf02e17F4A2D188a8A6bE93",
      "HyperProver": "0x486cD7EC5D37ff9bAF1be93e0c803305b602C007"
    },
    "42161": {
      "IntentSource": "0x983E3F7d2B1Ac28988125BA025f8b390132AFD98",
      "Inbox": "0x1c84ebA615203406Caf02e17F4A2D188a8A6bE93",
      "HyperProver": "0x486cD7EC5D37ff9bAF1be93e0c803305b602C007"
    },
    "10-pre": {
      "IntentSource": "0x58a8Bf532d3A27Cd8A9eAC04194b87229bca3f3A",
      "Inbox": "0xe0399683C20a79dDFEC54371B115743aE84c5F01",
      "HyperProver": "0xAe1ceB16004a8DaB2c980B3D7d2095d3C5bcBbCe"
    },
    "8453-pre": {
      "IntentSource": "0x58a8Bf532d3A27Cd8A9eAC04194b87229bca3f3A",
      "Inbox": "0xe0399683C20a79dDFEC54371B115743aE84c5F01",
      "HyperProver": "0xAe1ceB16004a8DaB2c980B3D7d2095d3C5bcBbCe"
    },
    "42161-pre": {
      "IntentSource": "0x58a8Bf532d3A27Cd8A9eAC04194b87229bca3f3A",
      "Inbox": "0xe0399683C20a79dDFEC54371B115743aE84c5F01",
      "HyperProver": "0xAe1ceB16004a8DaB2c980B3D7d2095d3C5bcBbCe"
    }
  } as const
